@@ -11,9 +11,9 @@
 #include <KLocalizedString>
 
 #include <QDialogButtonBox>
+#include <QGridLayout>
 #include <QLabel>
 #include <QLineEdit>
-#include <QGridLayout>
 #include <QPushButton>
 #include <QVBoxLayout>
 
@@ -25,9 +25,9 @@ KLinkDialog::KLinkDialog(QWidget *parent)
     setWindowTitle(i18nc("@title:window", "Manage Link"));
     setModal(true);
 
-    auto *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
 
-    auto *grid = new QGridLayout;
+    auto grid = new QGridLayout;
 
     textLabel = new QLabel(i18n("Link Text:"), this);
     textLineEdit = new QLineEdit(this);
