@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef EMOTICONLISTWIDGETSELECTOR_H
 #define EMOTICONLISTWIDGETSELECTOR_H
 
-#include <QListWidget>
 #include "kpimtextedit_private_export.h"
+#include <QListWidget>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class KPIMTEXTEDIT_TESTS_EXPORT EmoticonTextEditItem : public QListWidgetItem
 {
 public:
@@ -26,7 +27,7 @@ class KPIMTEXTEDIT_TESTS_EXPORT EmoticonListWidgetSelector : public QListWidget
     Q_OBJECT
 public:
     explicit EmoticonListWidgetSelector(QWidget *parent = nullptr);
-    ~EmoticonListWidgetSelector();
+    ~EmoticonListWidgetSelector() override;
 
     void setEmoticons(const QList<uint> &lst);
     void setEmoticons(const QStringList &lst);
