@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
   based on code from kopete
 
   SPDX-License-Identifier: LGPL-2.0-or-later
@@ -12,13 +12,14 @@
 
 #include <KActionMenu>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class EmoticonTextEditAction : public KActionMenu
 {
     Q_OBJECT
 public:
     explicit EmoticonTextEditAction(QObject *parent);
-    ~EmoticonTextEditAction();
+    ~EmoticonTextEditAction() override;
 
 Q_SIGNALS:
     void emoticonActivated(const QString &);
