@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
   based on code from kopete
 
   SPDX-License-Identifier: LGPL-2.0-or-later
@@ -16,7 +16,7 @@ using namespace KPIMTextEdit;
 EmoticonTextEditSelector::EmoticonTextEditSelector(QWidget *parent)
     : QWidget(parent)
 {
-    auto *lay = new QHBoxLayout(this);
+    auto lay = new QHBoxLayout(this);
     lay->setSpacing(0);
     lay->setContentsMargins(0, 0, 0, 0);
     mUnicodeTab = new EmoticonUnicodeTab(this);
@@ -31,8 +31,7 @@ EmoticonTextEditSelector::~EmoticonTextEditSelector()
 void EmoticonTextEditSelector::slotItemSelected(const QString &str)
 {
     Q_EMIT itemSelected(str);
-    if (isVisible() && parentWidget()
-        && parentWidget()->inherits("QMenu")) {
+    if (isVisible() && parentWidget() && parentWidget()->inherits("QMenu")) {
         parentWidget()->close();
     }
 }
