@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -10,7 +10,8 @@
 
 #include <KActionMenu>
 #include <QTextEdit>
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class TableActionMenuPrivate;
 
 class TableActionMenu : public KActionMenu
@@ -18,9 +19,10 @@ class TableActionMenu : public KActionMenu
     Q_OBJECT
 public:
     explicit TableActionMenu(QTextEdit *textEdit);
-    ~TableActionMenu();
+    ~TableActionMenu() override;
 
     void setRichTextMode(bool richTextMode);
+
 private:
     TableActionMenuPrivate *const d;
     friend class TableActionMenuPrivate;
