@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "richtexteditorwidget.h"
-#include "richtexteditor.h"
 #include "richtexteditfindbar.h"
+#include "richtexteditor.h"
 
-#include <QVBoxLayout>
 #include <QTextCursor>
+#include <QVBoxLayout>
 #include <texttospeech/texttospeechwidget.h>
 
 #include "slidecontainer.h"
@@ -100,7 +100,7 @@ QString RichTextEditorWidget::toPlainText() const
 
 void RichTextEditorWidget::init(RichTextEditor *customEditor)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     lay->setContentsMargins(0, 0, 0, 0);
     d->mTextToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
     lay->addWidget(d->mTextToSpeechWidget);
