@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef RICHTEXTEDITORWIDGET_H
@@ -24,9 +11,14 @@
 
 #include <QWidget>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class RichTextEditor;
 class RichTextEditorWidgetPrivate;
+/**
+ * @brief The RichTextEditorWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KPIMTEXTEDIT_EXPORT RichTextEditorWidget : public QWidget
 {
     Q_OBJECT
@@ -34,7 +26,7 @@ class KPIMTEXTEDIT_EXPORT RichTextEditorWidget : public QWidget
 public:
     explicit RichTextEditorWidget(QWidget *parent = nullptr);
     explicit RichTextEditorWidget(RichTextEditor *customEditor, QWidget *parent = nullptr);
-    ~RichTextEditorWidget();
+    ~RichTextEditorWidget() override;
 
     void clear();
 
@@ -61,7 +53,6 @@ public Q_SLOTS:
     void slotReplace();
 
 private:
-
     void slotHideFindBar();
     void init(RichTextEditor *customEditor = nullptr);
     RichTextEditorWidgetPrivate *const d;
