@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,13 +9,14 @@
 
 #include <QComboBox>
 #include <QLocale>
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class TextToSpeechLanguageComboBox : public QComboBox
 {
     Q_OBJECT
 public:
     explicit TextToSpeechLanguageComboBox(QWidget *parent = nullptr);
-    ~TextToSpeechLanguageComboBox();
+    ~TextToSpeechLanguageComboBox() override;
     void selectLocaleName(const QString &localeName);
     void updateAvailableLocales(const QVector<QLocale> &locales, const QLocale &current);
 };
