@@ -1,26 +1,26 @@
 /*
-    SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "testgeneratehtmlbuildergui.h"
-#include <QVBoxLayout>
+#include <KPIMTextEdit/MarkupDirector>
+#include <KPIMTextEdit/TextHTMLBuilder>
 #include <QApplication>
 #include <QLabel>
-#include <QTextEdit>
 #include <QPushButton>
-#include <KPIMTextEdit/TextHTMLBuilder>
-#include <KPIMTextEdit/MarkupDirector>
+#include <QTextEdit>
+#include <QVBoxLayout>
 
 TestGenerateHTMLBuilderGui::TestGenerateHTMLBuilderGui(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     QLabel *lab = new QLabel(QStringLiteral("html text"), this);
     mainLayout->addWidget(lab);
 
-    auto *htmlEdit = new QTextEdit(this);
+    auto htmlEdit = new QTextEdit(this);
     htmlEdit->setAcceptRichText(false);
     mainLayout->addWidget(htmlEdit);
 
@@ -30,7 +30,7 @@ TestGenerateHTMLBuilderGui::TestGenerateHTMLBuilderGui(QWidget *parent)
     lab = new QLabel(QStringLiteral("Generate Html"), this);
     mainLayout->addWidget(lab);
 
-    auto *generatedHtml = new QTextEdit(this);
+    auto generatedHtml = new QTextEdit(this);
     generatedHtml->setAcceptRichText(false);
     generatedHtml->setReadOnly(true);
     mainLayout->addWidget(generatedHtml);
@@ -38,16 +38,15 @@ TestGenerateHTMLBuilderGui::TestGenerateHTMLBuilderGui(QWidget *parent)
     lab = new QLabel(QStringLiteral("HTML from QTextEdit"), this);
     mainLayout->addWidget(lab);
 
-    auto *generatedHtmlFromTextEdit = new QTextEdit(this);
+    auto generatedHtmlFromTextEdit = new QTextEdit(this);
     generatedHtmlFromTextEdit->setAcceptRichText(false);
     generatedHtmlFromTextEdit->setReadOnly(true);
     mainLayout->addWidget(generatedHtmlFromTextEdit);
 
-
     lab = new QLabel(QStringLiteral("HTML from Grantlee"), this);
     mainLayout->addWidget(lab);
 
-    auto *generatedHtmlFromGrantlee = new QTextEdit(this);
+    auto generatedHtmlFromGrantlee = new QTextEdit(this);
     generatedHtmlFromGrantlee->setAcceptRichText(false);
     generatedHtmlFromGrantlee->setReadOnly(true);
     mainLayout->addWidget(generatedHtmlFromGrantlee);
@@ -55,13 +54,12 @@ TestGenerateHTMLBuilderGui::TestGenerateHTMLBuilderGui(QWidget *parent)
     lab = new QLabel(QStringLiteral("HTML from Grantlee to TextEdit"), this);
     mainLayout->addWidget(lab);
 
-    auto *generatedHtmlFromGrantleeToTextEdit = new QTextEdit(this);
+    auto generatedHtmlFromGrantleeToTextEdit = new QTextEdit(this);
     generatedHtmlFromGrantleeToTextEdit->setAcceptRichText(false);
     generatedHtmlFromGrantleeToTextEdit->setReadOnly(true);
     mainLayout->addWidget(generatedHtmlFromGrantleeToTextEdit);
 
-
-    connect(generateHtmlFromQTextEditButton, &QPushButton::clicked, this, [=]{
+    connect(generateHtmlFromQTextEditButton, &QPushButton::clicked, this, [=] {
         generatedHtml->setHtml(htmlEdit->toPlainText());
         generatedHtmlFromTextEdit->setPlainText(generatedHtml->document()->toHtml());
 
@@ -78,10 +76,8 @@ TestGenerateHTMLBuilderGui::TestGenerateHTMLBuilderGui(QWidget *parent)
 
 TestGenerateHTMLBuilderGui::~TestGenerateHTMLBuilderGui()
 {
-
 }
 
-
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
